Main public logs
Appearance
Combined display of all available logs of Haidhi Wiki. You can narrow down the view by selecting a log type, the username (case-sensitive), or the affected page (also case-sensitive).
- 08:25, 2 January 2026 SanzSkuy talk contribs created page OpenCL: Setup & Hello World (Created page with "Install OpenCL (untuk Nvidia) <syntaxhighligh lang=bash> sudo pacman -S opencl-headers ocl-icd opencl-nvidia </syntaxhighlight> main.cpp <syntaxhighlight lang=cpp> #include <CL/cl.h> #include <iostream> #include <vector> const char* kernelSource = R"( __kernel void vector_add(__global const float* a, __global const float* b, __global float* c) { int gid = get_global_id(0); c[gid] = a[gid] + b[gid]; } )"; int mai...")